==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+245"/>
      <source>Mesh</source>
      <translation>siatka</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation type="unfinished">Curve on mesh...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation type="unfinished">Curve on mesh</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-191"/>
      <source>Mesh</source>
      <translation>siatka</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Utwórz siatkę z kształtu...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Tesselacja obwiedni</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+106"/>
      <source>Mesh</source>
      <translation>siatka</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation>Utwórz sekcje z siatki i planu</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Przecięcie</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Mesh</source>
      <translation>siatka</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Przytnij siatkę za pomocą płaszczyzny</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Przycina siatkę za pomocą płaszczyzny</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Utwórz</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation type="unfinished">Close wire</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Wyczyść</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>Anuluj</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation type="unfinished">Wrong mesh picked</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>Nie wybrano żadnego punktu</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation type="unfinished">Curve on mesh</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Linia</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation type="unfinished">Snap tolerance to vertexes</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation type="unfinished"> px</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation type="unfinished">Split threshold</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation type="unfinished">Spline Approximation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation type="unfinished">Tolerance to mesh</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>Ciągłość</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation type="unfinished">Maximum curve degree</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation type="unfinished">Start</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Tesselacja</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Kształty</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>Opcje tworzenia siatki</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Standardowy</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation type="unfinished">Define segments by face colors</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation type="unfinished">Apply face colors to mesh</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation type="unfinished">Angular deviation:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation type="unfinished">Relative surface deviation</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>Maksymalna długość krawędzi:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>Stopień rozdrobnienia:</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Bardzo zgrubna</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>Zgrubnie</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>Umiarkowanie</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>Drobno</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Bardzo dokładna</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Zdefiniowana przez użytkownika</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>Stopnie rozmiaru siatki:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Elementy na krawędź:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>Elementy na promień krzywizny:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Optymalizuj powirzchnię</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>Elementy drugiego rzędu</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>Dominujące czworokąty</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>Ustawienia</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Odchylenie powierzchni</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>Max. Długość krawędzi:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+225"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Zaznacz najpierw obwiednię w celu utworzenia siatki</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>Brak dokumentu '%1'.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Select plane</source>
      <translation>Wybierz płaszczyznę</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation type="unfinished">Please select a plane at which you section the mesh.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Select plane</source>
      <translation>Wybierz płaszczyznę</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Wybierz płaszczyznę którą chcesz przyciąć siatkę.</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>Składnik_Siatki</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+290"/>
      <source>Mesh</source>
      <translation>siatka</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation>Krzywa na siatce...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation>Krzywa na siatce</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-235"/>
      <source>Mesh</source>
      <translation>siatka</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Utwórz siatkę z kształtu...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Tesselacja obwiedni</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+150"/>
      <source>Mesh</source>
      <translation>siatka</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation>Utwórz sekcje z siatki i planu</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Przecięcie</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Mesh</source>
      <translation>siatka</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Przytnij siatkę za pomocą płaszczyzny</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Przycina siatkę za pomocą płaszczyzny</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Utwórz</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation>Krzywa zamknięta</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Wyczyść</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>Anuluj</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation>Wybraną nieodpowiednią siatkę</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>Nie wybrano żadnego punktu</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation>Krzywa na siatce</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Linia</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation>Przyciągaj tolerancje do wierzchołków</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation>Próg połączenia</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation>Przybliżenie splajnu</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation>Tolerancja do siatki</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>Ciągłość</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation>Maksymalny stopień krzywej</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation>Start</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Tesselacja</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Kształty</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>Opcje tworzenia siatki</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Standardowy</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation>Zdefiniowanie segmentów przez kolory powierzchni</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation>Stosowanie kolorów powierzchni do siatki</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation>Odchylenie kątowe:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation>Względne odchylenie powierzchni:</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>Maksymalna długość krawędzi:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>Stopień rozdrobnienia:</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Bardzo zgrubna</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>Zgrubnie</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>Umiarkowanie</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>Drobno</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Bardzo dokładna</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Zdefiniowana przez użytkownika</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>Stopnie rozmiaru siatki:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Elementy na krawędź:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>Elementy na promień krzywizny:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Optymalizuj powierzchnię</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>Elementy drugiego rzędu</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>Dominujące czworokąty</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>Ustawienia</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Odchylenie powierzchni</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>Max. Długość krawędzi:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+226"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Zaznacz najpierw obwiednię w celu utworzenia siatki</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>Brak dokumentu '%1'.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+137"/>
      <source>Select plane</source>
      <translation>Wybierz płaszczyznę</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Wybierz płaszczyznę którą chcesz podzielić siatkę.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Select plane</source>
      <translation>Wybierz płaszczyznę</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Wybierz płaszczyznę którą chcesz przyciąć siatkę.</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Trim by plane</source>
      <translation>Przytnij płaszczyzną</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Select the side you want to keep.</source>
      <translation>Wybierz stronę, którą chcesz zachować.</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Inner</source>
      <translation>Wewnętrzny</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Outer</source>
      <translation>Zewnętrzny</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Split</source>
      <translation>Rozdziel</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>Składnik_Siatki</translation>
    </message>
  </context>
</TS>
